unit ChartConfig;

interface


uses VCLTee.Chart, VCLTee.TeEngine, Graphics, Windows;

type
  TChartColorType = (cctDisplay, cctPrinting);

  TChartConfig = class
  private
    class function GetFontColor(aConfigFor: TChartColorType): TColor; static;

  public
    class function MarksBackColor: TColor;
    class function MarkFontColor: TColor;
    class function MarkFontSize1: TColor;

    class procedure ConfigChart(aChart: TChart; aSwapAxis: boolean = false); overload;
    class procedure ConfigChartFontSize(aChart: TChart; aScaleFonts: boolean);


    class procedure ConfigMarks(const aChart: TChart; aScaleFonts: boolean); overload;
    class procedure ConfigMarks(aMarks: TSeriesMarks; aScaleFonts: boolean); overload;

    class procedure ConfigureChartColors(aConfigFor: TChartColorType; aChart: TChart);
    class procedure ConfigChartSeries(aConfigFor: TChartColorType; aChart: TChart);

    class property FontColor[aConfigFor: TChartColorType]: TColor read GetFontColor;
  end;




implementation

uses Math, VCLTee.TeCanvas, Controls, VCLTee.Series, System.SysUtils, Forms, VCLTee.TeeTools;

{ TChartConfig }

const
  TITLE_FONT_NAME = 'Segoe UI';
  STANDARD_FONT_NAME = 'Segoe UI';

class procedure TChartConfig.ConfigChartFontSize(aChart: TChart; aScaleFonts: boolean);
var
  lScale: double;
  lFont12: integer;
  lFont10: integer;
  lFont9: integer;
  lFont8: integer;
  I: integer;
begin
  if aScaleFonts then begin
    lScale := (aChart.PixelsPerInch / 96);

    lFont12 := Round(lScale * 12);
    lFont10 := Round(lScale * 10);
    lFont9 := Round(lScale * 9);
    lFont8 := Round(lScale * 8);
  end else begin
    lFont12 := 12;
    lFont10 := 10;
    lFont9 := 9;
    lFont8 := 8;
  end;

  aChart.Title.Font.Size := lFont12;
  aChart.Subtitle.Font.Size := lFont10;
  aChart.BottomAxis.Title.Font.Size := lFont10;
  aChart.BottomAxis.LabelsFont.Size := lFont9;
  aChart.LeftAxis.Title.Font.Size := lFont10;
  aChart.LeftAxis.LabelsFont.Size := lFont9;
  aChart.Legend.Font.Size := lFont9;
  aChart.BottomAxis.LabelsFont.Size := lFont9;
  aChart.BottomAxis.LabelsFormat.Font.size := lFont9;
  aChart.BottomAxis.LabelsFont.Size := lFont9;
  aChart.DepthAxis.LabelsFont.size := lFont8;
  aChart.DepthAxis.LabelsFormat.Font.size := lFont8;
  aChart.DepthAxis.Shape.Font.Size := lFont8;
  aChart.DepthAxis.Title.Font.Size := lFont8;
  aChart.DepthTopAxis.LabelsFont.Size := lFont8;
  aChart.DepthTopAxis.LabelsFormat.Font.Size := lFont8;
  aChart.DepthTopAxis.Shape.Font.Size := lFont8;
  aChart.DepthTopAxis.Title.Font.Size := lFont8;
  aChart.Foot.Font.Size := lFont8;
  aChart.LeftAxis.Shape.Font.Size := lFont8;
  aChart.Legend.Title.Font.Size := lFont8;
  aChart.RightAxis.LabelsFont.Size := lFont8;
  aChart.RightAxis.LabelsFormat.Font.Size := lFont8;
  aChart.RightAxis.Shape.Font.Size := lFont8;
  aChart.RightAxis.Title.Font.Size := lFont8;
  aChart.SubFoot.Font.Size := lFont9;
  aChart.SubTitle.Font.Size := lFont8;
  aChart.TopAxis.LabelsFont.Size := lFont8;
  aChart.TopAxis.LabelsFormat.Font.Size := lFont8;
  aChart.TopAxis.Shape.Font.Size := lFont8;
  aChart.TopAxis.Title.Font.Size := lFont8;

  for I := 0 to aChart.Tools.Count-1 do
    if aChart.Tools[I] is TAnnotationTool then
      TAnnotationTool(aChart.Tools[I]).Shape.Font.Size := lFont8;
end;

class procedure TChartConfig.ConfigChart(aChart: TChart; aSwapAxis: boolean);
var
 lAxis: TChartAxis;
  I: Integer;
begin
  ConfigChartFontSize(aChart, True);

  aChart.Title.Font.Style := [];
  aChart.Title.Font.Name := TITLE_FONT_NAME;
  aChart.Title.Font.Color := clBlack;

  aChart.Subtitle.Font.Style := [];
  aChart.Subtitle.Font.Name := TITLE_FONT_NAME;
  aChart.Subtitle.Font.Color := clBlack;

  aChart.Shadow.Visible := false;
  aChart.BevelInner := bvNone;
  aChart.BevelOuter := bvNone;

  if aSwapAxis then
    lAxis := aChart.BottomAxis
  else
    lAxis := aChart.LeftAxis;

  lAxis.Title.Font.Style := [];
  lAxis.Title.Font.Name := STANDARD_FONT_NAME;
  lAxis.Title.Font.Color := clBlack;

  lAxis.LabelsFont.Name := STANDARD_FONT_NAME;
  lAxis.LabelsSeparation := ifthen(aSwapAxis, 50, 100);
  lAxis.Axis.Width := 1;
  lAxis.Ticks.Visible := False;
  lAxis.MinorTicks.Visible := False;
  lAxis.TicksInner.Visible := False;
  lAxis.Grid.Color := clBlack;
  lAxis.Grid.Style := psDot;

  if aSwapAxis then
    lAxis := aChart.LeftAxis
  else
    lAxis := aChart.BottomAxis;

  lAxis.Title.Font.Style := [];
  lAxis.Title.Font.Name := STANDARD_FONT_NAME;
  lAxis.Title.Font.Color := clBlack;

  lAxis.Axis.Width := 1;
  lAxis.Grid.Visible := False;
  lAxis.MinorTicks.Visible := False;
  lAxis.TicksInner.Visible := False;

  lAxis.LabelsSeparation := ifthen(aSwapAxis, 100, 50);

  aChart.Color := clWhite;
  aChart.RightAxis.Visible := False;
  aChart.TopAxis.Visible := False;
  aChart.BackWall.Visible := False;

  aChart.LeftWall.Color := clWhite;

  aChart.Legend.Font.Name := STANDARD_FONT_NAME;

  aChart.Legend.Symbol.Squared := True;
  aChart.Legend.Symbol.Pen.Visible := False;
  aChart.Legend.Symbol.Shadow.Visible := False;
  aChart.Legend.Gradient.Visible := False;
  aChart.Legend.Shadow.Visible := False;
  aChart.Legend.Frame.Visible := False;
  aChart.Legend.Transparent := True;

  aChart.View3D := False;
  aChart.Gradient.Visible := False;
  aChart.Zoom.Allow := false;

  aChart.BottomAxis.LabelsFont.Name := STANDARD_FONT_NAME;

  aChart.BottomAxis.LabelsFormat.Font.Name := STANDARD_FONT_NAME;

  aChart.BottomAxis.Shape.Font.Name := STANDARD_FONT_NAME;

  aChart.DepthAxis.LabelsFont.Name := STANDARD_FONT_NAME;

  aChart.DepthAxis.LabelsFormat.Font.Name := STANDARD_FONT_NAME;

  aChart.DepthAxis.Shape.Font.Name := STANDARD_FONT_NAME;

  aChart.DepthAxis.Title.Font.Name := STANDARD_FONT_NAME;

  aChart.DepthTopAxis.LabelsFont.Name := STANDARD_FONT_NAME;

  aChart.DepthTopAxis.LabelsFormat.Font.Name := STANDARD_FONT_NAME;

  aChart.DepthTopAxis.Shape.Font.Name := STANDARD_FONT_NAME;

  aChart.DepthTopAxis.Title.Font.Name := STANDARD_FONT_NAME;

  aChart.Foot.Font.Name := STANDARD_FONT_NAME;

  aChart.LeftAxis.Shape.Font.Name := STANDARD_FONT_NAME;

  aChart.Legend.Title.Font.Name := STANDARD_FONT_NAME;

  aChart.RightAxis.LabelsFont.Name := STANDARD_FONT_NAME;

  aChart.RightAxis.LabelsFormat.Font.Name := STANDARD_FONT_NAME;

  aChart.RightAxis.Shape.Font.Name := STANDARD_FONT_NAME;

  aChart.RightAxis.Title.Font.Name := STANDARD_FONT_NAME;

  aChart.SubFoot.Font.Name := STANDARD_FONT_NAME;

  aChart.SubTitle.Font.Name := STANDARD_FONT_NAME;

  aChart.TopAxis.LabelsFont.Name := STANDARD_FONT_NAME;

  aChart.TopAxis.LabelsFormat.Font.Name := STANDARD_FONT_NAME;

  aChart.TopAxis.Shape.Font.Name := STANDARD_FONT_NAME;

  aChart.TopAxis.Title.Font.Name := STANDARD_FONT_NAME;

  for I := 0 to aChart.SeriesCount-1 do
    ConfigMarks(aChart[I].Marks, True);
end;


class procedure TChartConfig.ConfigChartSeries(aConfigFor: TChartColorType; aChart: TChart);
var
  I: Integer;
  lFontColor: TColor;
  lLineColor: TColor;
  lSeries: TChartSeries;
  lLineSeries: TLineSeries;
  lAreaSeries: TAreaSeries;
  lBarSeries: TBarSeries;
  lPieSeries: TPieSeries;
  lHorzBarSeries: THorizBarSeries;
  lPtSeries: TPointSeries;
begin
  lFontColor := clBlack;
  lLineColor := clGray;

  for I := 0 to aChart.SeriesCount-1 do begin
    lSeries := aChart[I];
    lSeries.Marks.Font.Color := lFontColor;

    if lSeries is TLineSeries then begin
      lLineSeries := TLineSeries(lSeries);
      //lLineSeries.LinePen.Color := lLineColor;
      lLineSeries.Marks.Callout.Brush.Color := lLineColor;
      lLineSeries.Marks.Callout.Pen.Color := lLineColor;
      lLineSeries.Marks.Font.Brush.Color := lLineColor;
      lLineSeries.Marks.Font.OutLine.Color := lLineColor;
      lLineSeries.Marks.Frame.Color := lLineColor;
      lLineSeries.Marks.Symbol.Emboss.Color := lLineColor;
      lLineSeries.Marks.Symbol.Frame.Color := lLineColor;
      lLineSeries.Marks.Symbol.Pen.Color := lLineColor;
      lLineSeries.Marks.Symbol.Shadow.Color := lLineColor;
      lLineSeries.OutLine.Color := lLineColor;
      lLineSeries.Pointer.Pen.Color := lLineColor;
    end else if lSeries is TPieSeries then begin
      lPieSeries := TPieSeries(lSeries);
      lPieSeries.Marks.Callout.Brush.Color := lLineColor;
      lPieSeries.Marks.Callout.Pen.Color := lLineColor;
      lPieSeries.Marks.Font.Brush.Color := lLineColor;
      lPieSeries.Marks.Font.OutLine.Color := lLineColor;
      lPieSeries.Marks.Frame.Color := lLineColor;
      lPieSeries.Marks.Symbol.Emboss.Color := lLineColor;
      lPieSeries.Marks.Symbol.Frame.Color := lLineColor;
      lPieSeries.Marks.Symbol.Pen.Color := lLineColor;
      lPieSeries.Marks.Symbol.Shadow.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.DividingLines.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Emboss.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Font.Brush.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Font.OutLine.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Frame.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Shadow.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Symbol.Pen.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Title.Font.Brush.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Title.Font.OutLine.Color := lLineColor;
      lPieSeries.OtherSlice.Legend.Title.Frame.Color := lLineColor;
      lPieSeries.PiePen.Color := lLineColor;
    end else if lSeries is TAreaSeries then begin
      lAreaSeries := TAreaSeries(lSeries);
      lAreaSeries.AreaLinesPen.Color := lLineColor;
      lAreaSeries.LinePen.Color := lLineColor;
      lAreaSeries.Marks.Callout.Brush.Color := lLineColor;
      lAreaSeries.Marks.Callout.Pen.Color := lLineColor;
      lAreaSeries.Marks.Font.Brush.Color := lLineColor;
      lAreaSeries.Marks.Font.OutLine.Color := lLineColor;
      lAreaSeries.Marks.Frame.Color := lLineColor;
      lAreaSeries.Marks.Symbol.Emboss.Color := lLineColor;
      lAreaSeries.Marks.Symbol.Frame.Color := lLineColor;
      lAreaSeries.Marks.Symbol.Pen.Color := lLineColor;
      lAreaSeries.Marks.Symbol.Shadow.Color := lLineColor;
      lAreaSeries.Pointer.Pen.Color := lLineColor;
    end else if lSeries is TBarSeries then begin
      lBarSeries := TBarSeries(lSeries);
      lBarSeries.BarPen.Color := lLineColor;
      lBarSeries.Marks.Callout.Brush.Color := lLineColor;
      lBarSeries.Marks.Callout.Pen.Color := lLineColor;
      lBarSeries.Marks.Font.Brush.Color := lLineColor;
      lBarSeries.Marks.Font.OutLine.Color := lLineColor;
      lBarSeries.Marks.Frame.Color := lLineColor;
      lBarSeries.Marks.Symbol.Emboss.Color := lLineColor;
      lBarSeries.Marks.Symbol.Frame.Color := lLineColor;
      lBarSeries.Marks.Symbol.Pen.Color := lLineColor;
      lBarSeries.Marks.Symbol.Shadow.Color := lLineColor;
      lBarSeries.TickLines.Color := lLineColor;
    end else if lSeries is THorizBarSeries then begin
      lHorzBarSeries :=  THorizBarSeries(lSeries);

      lHorzBarSeries.BarPen.Color := lLineColor;
      lHorzBarSeries.Marks.Callout.Brush.Color := lLineColor;
      lHorzBarSeries.Marks.Callout.Pen.Color := lLineColor;
      lHorzBarSeries.Marks.Font.Brush.Color := lLineColor;
      lHorzBarSeries.Marks.Font.OutLine.Color := lLineColor;
      lHorzBarSeries.Marks.Frame.Color := lLineColor;
      lHorzBarSeries.Marks.Symbol.Emboss.Color := lLineColor;
      lHorzBarSeries.Marks.Symbol.Frame.Color := lLineColor;
      lHorzBarSeries.Marks.Symbol.Pen.Color := lLineColor;
      lHorzBarSeries.Marks.Symbol.Shadow.Color := lLineColor;
      lHorzBarSeries.TickLines.Color := lLineColor;

    end else if lSEries is TPointSeries then begin
      lPtSeries := TPointSeries(lSeries);
			lPtSeries.Marks.Callout.Brush.Color := clBlack;
			lPtSeries.Marks.Callout.Pen.Color := clBlack;
			lPtSeries.Marks.Font.Brush.Color := clBlack;
			lPtSeries.Marks.Font.Color := clBlack;
			lPtSeries.Marks.Font.OutLine.Color := clBlack;
			lPtSeries.Marks.Frame.Color := clBlack;
			lPtSeries.Marks.Symbol.Emboss.Color := clBlack;
			lPtSeries.Marks.Symbol.Frame.Color := clBlack;
			lPtSeries.Marks.Symbol.Pen.Color := clBlack;
			lPtSeries.Marks.Symbol.Shadow.Color := clBlack;
			lPtSeries.Pointer.Pen.Color := clBlack;
    end else begin
      {$if defined(Debug)}
      {$if defined(CodeSite)}
      CodeSite.Send(lSeries.ClassName, lSeries);
      {$endif}
      raise Exception.Create('Series Class not hanleded for coloring: ' + lSeries.ClassName);
      {$endif}
    end;
  end;
end;

class procedure TChartConfig.ConfigMarks(const aChart: TChart; aScaleFonts: boolean);
var
  I: Integer;
begin
  for I := 0 to aChart.SeriesCount-1 do
    ConfigMarks(aChart[I].Marks, aScaleFonts);
end;

class procedure TChartConfig.ConfigMarks(aMarks: TSeriesMarks; aScaleFonts: boolean);
var
  lScale: double;
begin
  if aScaleFonts and assigned(Application.MainForm) then
    lScale := Round(Application.MainForm.PixelsPerInch / 96) {$if defined(ChartScaleFonts)} * FFontScale {$endif}
  else
    lScale := {$if defined(ChartScaleFonts)} FFontScale {$else} 1  {$endif};
  aMarks.Font.Size := Round(lScale * MarkFontSize1);
  aMarks.Transparent := True;
end;

class procedure TChartConfig.ConfigureChartColors(aConfigFor: TChartColorType; aChart: TChart);
var
  lFontColor: TColor;
  lFormColor: TColor;
  lLineColor: Integer;
  lTitleFontColor: Integer;
  lAxisTitleFontColor: Integer;
begin
  ConfigChartFontSize(aChart, aConfigFor = cctDisplay);
  if aConfigFor = cctDisplay then begin
    lTitleFontColor := clBlack;
    lAxisTitleFontColor := clDkGray;
    lFontColor := clBlack;
    lFormColor := clWhite;
    lLineColor := clBlack;
  end else begin
    lTitleFontColor := clRed;
    lAxisTitleFontColor := clGreen;
    lFontColor := clNavy;
    lFormColor := clNavy;
    lLineColor := clNavy;
  end;

  aChart.Color := lFormColor;
  aChart.Foot.Font.Color := lFontColor;
  aChart.Legend.Font.Color := lFontColor;
  aChart.Legend.Title.Font.Color := lFontColor;
  aChart.SubFoot.Font.Color := lFontColor;

  aChart.Title.Font.Color := lTitleFontColor;
  aChart.SubTitle.Font.Color := lTitleFontColor;

  aChart.DepthAxis.Title.Font.Color := lFontColor;

  aChart.BottomAxis.Title.Font.Color := lAxisTitleFontColor;
  aChart.LeftAxis.Title.Font.Color := lAxisTitleFontColor;
  aChart.RightAxis.Title.Font.Color := lAxisTitleFontColor;
  aChart.TopAxis.Title.Font.Color := lAxisTitleFontColor;

  aChart.BottomAxis.LabelsFormat.Font.Color := lFontColor;
  aChart.DepthAxis.LabelsFormat.Font.Color := lFontColor;
  aChart.DepthTopAxis.LabelsFormat.Font.Color := lFontColor;
  aChart.DepthTopAxis.Title.Font.Color := lFontColor;
  aChart.LeftAxis.LabelsFormat.Font.Color := lFontColor;
  aChart.RightAxis.LabelsFormat.Font.Color := lFontColor;
  aChart.TopAxis.LabelsFormat.Font.Color := lFontColor;

  // line colors
  aChart.BackWall.Pen.Color := lLineColor;
  aChart.BackWall.Visible := false;
  aChart.Border.Color := lLineColor;
  aChart.BottomAxis.LabelsFont.Brush.Color := lLineColor;
  aChart.BottomAxis.LabelsFont.OutLine.Color := lLineColor;
  aChart.BottomAxis.LabelsFormat.Emboss.Color := lLineColor;
  aChart.BottomAxis.LabelsFormat.Font.Brush.Color := lLineColor;
  aChart.BottomAxis.LabelsFormat.Font.OutLine.Color := lLineColor;
  aChart.BottomAxis.LabelsFormat.Frame.Color := lLineColor;
  aChart.BottomAxis.LabelsFormat.Shadow.Color := lLineColor;
  aChart.BottomAxis.MinorGrid.Color := lLineColor;
  aChart.BottomAxis.Shape.Emboss.Color := lLineColor;
  aChart.BottomAxis.Shape.Font.Brush.Color := lLineColor;
  aChart.BottomAxis.Shape.Font.OutLine.Color := lLineColor;
  aChart.BottomAxis.Shape.Shadow.Color := lLineColor;
  aChart.BottomAxis.Title.Emboss.Color := lLineColor;
  aChart.BottomAxis.Title.Font.Brush.Color := lLineColor;
  aChart.BottomAxis.Title.Font.OutLine.Color := lLineColor;
  aChart.BottomAxis.Title.Pen.Color := lLineColor;
  aChart.BottomAxis.Title.Shadow.Color := lLineColor;
  aChart.BottomWall.Pen.Color := lLineColor;
  aChart.DepthAxis.LabelsFont.Brush.Color := lLineColor;
  aChart.DepthAxis.LabelsFont.OutLine.Color := lLineColor;
  aChart.DepthAxis.LabelsFormat.Emboss.Color := lLineColor;
  aChart.DepthAxis.LabelsFormat.Font.Brush.Color := lLineColor;
  aChart.DepthAxis.LabelsFormat.Font.OutLine.Color := lLineColor;
  aChart.DepthAxis.LabelsFormat.Frame.Color := lLineColor;
  aChart.DepthAxis.LabelsFormat.Shadow.Color := lLineColor;
  aChart.DepthAxis.MinorGrid.Color := lLineColor;
  aChart.DepthAxis.Shape.Emboss.Color := lLineColor;
  aChart.DepthAxis.Shape.Font.Brush.Color := lLineColor;
  aChart.DepthAxis.Shape.Font.OutLine.Color := lLineColor;
  aChart.DepthAxis.Shape.Shadow.Color := lLineColor;
  aChart.DepthAxis.Title.Emboss.Color := lLineColor;
  aChart.DepthAxis.Title.Font.Brush.Color := lLineColor;
  aChart.DepthAxis.Title.Font.OutLine.Color := lLineColor;
  aChart.DepthAxis.Title.Pen.Color := lLineColor;
  aChart.DepthAxis.Title.Shadow.Color := lLineColor;
  aChart.DepthTopAxis.LabelsFont.Brush.Color := lLineColor;
  aChart.DepthTopAxis.LabelsFont.OutLine.Color := lLineColor;
  aChart.DepthTopAxis.LabelsFormat.Emboss.Color := lLineColor;
  aChart.DepthTopAxis.LabelsFormat.Font.Brush.Color := lLineColor;
  aChart.DepthTopAxis.LabelsFormat.Font.OutLine.Color := lLineColor;
  aChart.DepthTopAxis.LabelsFormat.Frame.Color := lLineColor;
  aChart.DepthTopAxis.LabelsFormat.Shadow.Color := lLineColor;
  aChart.DepthTopAxis.MinorGrid.Color := lLineColor;
  aChart.DepthTopAxis.Shape.Emboss.Color := lLineColor;
  aChart.DepthTopAxis.Shape.Font.Brush.Color := lLineColor;
  aChart.DepthTopAxis.Shape.Font.OutLine.Color := lLineColor;
  aChart.DepthTopAxis.Shape.Shadow.Color := lLineColor;
  aChart.DepthTopAxis.Title.Emboss.Color := lLineColor;
  aChart.DepthTopAxis.Title.Font.Brush.Color := lLineColor;
  aChart.DepthTopAxis.Title.Font.OutLine.Color := lLineColor;
  aChart.DepthTopAxis.Title.Pen.Color := lLineColor;
  aChart.DepthTopAxis.Title.Shadow.Color := lLineColor;
  aChart.Foot.Emboss.Color := lLineColor;
  aChart.Foot.Font.OutLine.Color := lLineColor;
  aChart.Foot.Frame.Color := lLineColor;
  aChart.Foot.Shadow.Color := lLineColor;
  aChart.Frame.Color := lLineColor;
  aChart.LeftAxis.LabelsFont.Brush.Color := lLineColor;
  aChart.LeftAxis.LabelsFont.OutLine.Color := lLineColor;
  aChart.LeftAxis.LabelsFormat.Emboss.Color := lLineColor;
  aChart.LeftAxis.LabelsFormat.Font.Brush.Color := lLineColor;
  aChart.LeftAxis.LabelsFormat.Font.OutLine.Color := lLineColor;
  aChart.LeftAxis.LabelsFormat.Frame.Color := lLineColor;
  aChart.LeftAxis.LabelsFormat.Shadow.Color := lLineColor;
  aChart.LeftAxis.MinorGrid.Color := lLineColor;
  aChart.LeftAxis.Shape.Emboss.Color := lLineColor;
  aChart.LeftAxis.Shape.Font.Brush.Color := lLineColor;
  aChart.LeftAxis.Shape.Font.OutLine.Color := lLineColor;
  aChart.LeftAxis.Shape.Shadow.Color := lLineColor;
  aChart.LeftAxis.Title.Emboss.Color := lLineColor;
  aChart.LeftAxis.Title.Font.Brush.Color := lLineColor;
  aChart.LeftAxis.Title.Font.OutLine.Color := lLineColor;
  aChart.LeftAxis.Title.Pen.Color := lLineColor;
  aChart.LeftAxis.Title.Shadow.Color := lLineColor;
  aChart.LeftWall.Pen.Color := lLineColor;
  aChart.Legend.DividingLines.Color := lLineColor;
  aChart.Legend.Emboss.Color := lLineColor;
  aChart.Legend.Font.Brush.Color := lLineColor;
  aChart.Legend.Font.OutLine.Color := lLineColor;
  aChart.Legend.Frame.Color := lLineColor;
  aChart.Legend.Shadow.Color := lLineColor;
  aChart.Legend.Symbol.Pen.Color := lLineColor;
  aChart.Legend.Title.Font.Brush.Color := lLineColor;
  aChart.Legend.Title.Font.OutLine.Color := lLineColor;
  aChart.Legend.Title.Frame.Color := lLineColor;
  aChart.RightAxis.LabelsFont.Brush.Color := lLineColor;
  aChart.RightAxis.LabelsFont.OutLine.Color := lLineColor;
  aChart.RightAxis.LabelsFormat.Emboss.Color := lLineColor;
  aChart.RightAxis.LabelsFormat.Font.Brush.Color := lLineColor;
  aChart.RightAxis.LabelsFormat.Font.OutLine.Color := lLineColor;
  aChart.RightAxis.LabelsFormat.Frame.Color := lLineColor;
  aChart.RightAxis.LabelsFormat.Shadow.Color := lLineColor;
  aChart.RightAxis.MinorGrid.Color := lLineColor;
  aChart.RightAxis.Shape.Emboss.Color := lLineColor;
  aChart.RightAxis.Shape.Font.Brush.Color := lLineColor;
  aChart.RightAxis.Shape.Font.OutLine.Color := lLineColor;
  aChart.RightAxis.Shape.Shadow.Color := lLineColor;
  aChart.RightAxis.Title.Emboss.Color := lLineColor;
  aChart.RightAxis.Title.Font.Brush.Color := lLineColor;
  aChart.RightAxis.Title.Font.OutLine.Color := lLineColor;
  aChart.RightAxis.Title.Pen.Color := lLineColor;
  aChart.RightAxis.Title.Shadow.Color := lLineColor;
  aChart.RightWall.Pen.Color := lLineColor;
  aChart.SubFoot.Emboss.Color := lLineColor;
  aChart.SubFoot.Font.OutLine.Color := lLineColor;
  aChart.SubFoot.Frame.Color := lLineColor;
  aChart.SubFoot.Shadow.Color := lLineColor;
  aChart.SubTitle.Emboss.Color := lLineColor;
  aChart.SubTitle.Font.OutLine.Color := lLineColor;
  aChart.SubTitle.Frame.Color := lLineColor;
  aChart.SubTitle.Shadow.Color := lLineColor;
  aChart.Title.Emboss.Color := lLineColor;
  aChart.Title.Font.OutLine.Color := lLineColor;
  aChart.Title.Frame.Color := lLineColor;
  aChart.Title.Shadow.Color := lLineColor;
  aChart.TopAxis.LabelsFont.Brush.Color := lLineColor;
  aChart.TopAxis.LabelsFont.OutLine.Color := lLineColor;
  aChart.TopAxis.LabelsFormat.Emboss.Color := lLineColor;
  aChart.TopAxis.LabelsFormat.Font.Brush.Color := lLineColor;
  aChart.TopAxis.LabelsFormat.Font.OutLine.Color := lLineColor;
  aChart.TopAxis.LabelsFormat.Frame.Color := lLineColor;
  aChart.TopAxis.LabelsFormat.Shadow.Color := lLineColor;
  aChart.TopAxis.MinorGrid.Color := lLineColor;
  aChart.TopAxis.Shape.Emboss.Color := lLineColor;
  aChart.TopAxis.Shape.Font.Brush.Color := lLineColor;
  aChart.TopAxis.Shape.Font.OutLine.Color := lLineColor;
  aChart.TopAxis.Shape.Shadow.Color := lLineColor;
  aChart.TopAxis.Title.Emboss.Color := lLineColor;
  aChart.TopAxis.Title.Font.Brush.Color := lLineColor;
  aChart.TopAxis.Title.Font.OutLine.Color := lLineColor;
  aChart.TopAxis.Title.Pen.Color := lLineColor;
  aChart.TopAxis.Title.Shadow.Color := lLineColor;

  ConfigChartSeries(aConfigFor, aChart);
  ConfigMarks(aChart, aConfigFor = cctDisplay);
end;

class function TChartConfig.GetFontColor(aConfigFor: TChartColorType): TColor;
begin
  if aConfigFor = cctPrinting then
    result := clBlack
  else
    result := clBlack;
end;

class function TChartConfig.MarkFontColor: TColor;
begin
  result := clBlack;
end;

class function TChartConfig.MarkFontSize1: TColor;
begin
  result := 9;
end;

class function TChartConfig.MarksBackColor: TColor;
begin
  result := $00ECE4D3; //FMarksBackColor;
end;

initialization

end.
