unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, VCLTee.Series, VCLTee.TeEngine, VCLTee.TeCanvas,
  Vcl.ExtCtrls, VCLTee.TeeProcs, VCLTee.Chart, Vcl.ComCtrls, Vcl.StdCtrls;

const
  UM_CREATE_IMAGE = WM_USER;

{x$define MonitorDPIChangeEvent}

type
  TForm1 = class(TForm)
    PageControl1: TPageControl;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    chr72tHistoricRates: TChart;
    srsHistoricRate: TLineSeries;
    pnlHeader: TPanel;
    btnCreateImage: TButton;
    btnRemoveImage: TButton;
    chrt72t: TChart;
    srsValues: THorizBarSeries;
    procedure btnCreateImageClick(Sender: TObject);
    procedure btnRemoveImageClick(Sender: TObject);
    procedure PageControl1Change(Sender: TObject);
  private
    { Private declarations }
    procedure UpdateControls;
    procedure UMCreateImage(var aMsg: TMessage); message UM_CREATE_IMAGE;
  protected
    procedure DoShow; override;
    {$if defined(MonitorDPIChangeEvent)}
    procedure DoAfterMonitorDpiChanged(OldDPI, NewDPI: Integer); override;
    {$endif}
  public
    { Public declarations }
    constructor Create(aOwner: TComponent); override;
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}
uses ChartCOnfig, CodeSIteLogging;

procedure WrapLeftAxisTitle(aChart: TChart; const aHeight: Integer);
var
  lOneLineTitle: String;
  lTitleHeight: Integer;
  lTitle: TChartAxisTitle;
  lHeight: Integer;
begin
  Assert(assigned(aChart));

  aChart.Draw;

  lTitle := aChart.Axes.Left.Title;
  lOneLineTitle := StringReplace(lTitle.Text, sLineBreak, ' ', [rfReplaceAll]);
  lOneLineTitle := StringReplace(lOneLineTitle, '  ', ' ', [rfReplaceAll]);
  aChart.Canvas.AssignFont(lTitle.Font);

  lHeight:=aHeight;
  if (aChart.Legend.Alignment=laTop) or (aChart.Legend.Alignment=laBottom) then
     lHeight:=aChart.ChartRect.Height*aHeight div aChart.Height;

  if lHeight < aChart.Canvas.TextWidth(lOneLineTitle) then
    lTitle.Text := WrapText(lOneLineTitle, sLineBreak, [' '], lHeight div lTitle.Font.Size)
  else
    lTitle.Text := lOneLineTitle;

  lTitleHeight:=Abs( (lTitle.Text.CountChar(#13) + 1) * lTitle.Font.Height);
  aChart.MarginLeft := Round((lTitleHeight + 5) * 100 / aChart.Width);
end;

procedure AssignChartToGraphic(aChart: TChart; const aRect: TRect; aGraphic: TGraphic; aTransparent: boolean = false);
var
  lHoldShadow: boolean;
  I: Integer;
  lBoolArray: array of boolean;
  lHoldBevel: TBevelCut;
  lHoldColor: TColor;
  lHoldGradientVisible: boolean;
  lMetafile: TMetafile;
  {$ifopt C+}
  lCanvasClassName: string;
  {$endif}
  lBmp: TBitmap;
  lCanvasClass: TCanvas3DClass;
  lHoldHover: Boolean;
begin
  {$ifopt C+}
  lCanvasClassName := aChart.Canvas.ClassName;
  {$endif}
  lCanvasClass := TCanvas3DClass(aChart.Canvas.ClassType);
  if lCanvasClass <> TTeeCanvas3D then
    aChart.Canvas := TTeeCanvas3D.Create;

  lHoldGradientVisible := aChart.Gradient.Visible;
  lHoldColor := aChart.Color;
  lHoldBevel := aChart.BevelOuter;
  lHoldShadow := aChart.Shadow.Visible;
  lHoldHover := aChart.Hover.Visible;

  try
    SetLength(lBoolArray, aChart.SeriesCount);
    for I := 0 to aChart.SeriesCount - 1 do    // Iterate
      if aChart.Series[I] is TPieSeries then begin
        lBoolArray[I] := TPieSeries(aChart.Series[I]).Circled;
        TPieSeries(aChart.Series[I]).Circled := True;
      end else
        lBoolArray[I] := True;


    aChart.Gradient.Visible  := false;
    if not aTransparent then
      aChart.Color := clWhite
    else
      aChart.Color := VCL.Graphics.clNone; //clWhite;
    aChart.BevelOuter := bvNone;
    aChart.BevelInner := bvNone;
    aChart.Shadow.Visible := False;
    aChart.Hover.Visible := false;

    if assigned(aChart.OnResize) then
      //WrapLeftAxisTitle(aChart, Trunc(aRect.Height * 0.8));
      WrapLeftAxisTitle(aChart, aRect.Height);


    if aGraphic is TMetafile then begin
      lMetafile := aChart.TeeCreateMetafile(false, aRect);
      try
        aGraphic.Assign(lMetafile);
      finally
        lMetafile.Free;
      end;
    end else begin
      lBmp := aChart.TeeCreateBitmap(clWhite, aRect);
      try
        aGraphic.Assign(lBmp);
      finally
        lBmp.Free;
      end;
    end;
  finally
    aChart.Hover.Visible := lHoldHover;
    aChart.Shadow.Visible := lHoldShadow;
    aChart.Gradient.Visible := lHoldGradientVisible;
    aChart.Color := lHoldColor;
    aChart.BevelOuter := lHoldBevel;
    for I := 0 to aChart.SeriesCount - 1 do    // Iterate
      if aChart.Series[I] is TPieSeries then
        TPieSeries(aChart.Series[I]).Circled := lBoolArray[I];
    if (lCanvasClass <> aChart.Canvas.ClassType) then
      aChart.Canvas := lCanvasClass.Create;
    if assigned(aChart.OnResize) then
      WrapLeftAxisTitle(aChart, aChart.Height);
  end;

  {$ifopt C+}
  assert(SameText(lCanvasClassName, aChart.Canvas.ClassName),
    Format('Chart canvas should be %s but is %s', [lCanvasClassName, aChart.Canvas.ClassName]));
  {$endif}
end;


{ TForm1 }

procedure TForm1.btnCreateImageClick(Sender: TObject);
var
  lChart: TChart;
  lts: TTabSheet;
  limg: TImage;
  lIdx: Integer;
begin
  lIdx := PageControl1.ActivePageIndex;

  lts := TTabSheet.Create(self);
  lts.Caption := 'Image';
  lts.PageControl := PageControl1;

  limg := TImage.Create(self);
  limg.Parent := lts;
  limg.Align := alClient;

  PageControl1.ActivePageIndex := lts.PageIndex;

  PostMessage(handle, UM_CREATE_IMAGE, lIdx, lts.PageIndex);
  Caption := inttostr(PageControl1.ActivePageIndex);





end;

procedure TForm1.btnRemoveImageClick(Sender: TObject);
begin
  PageControl1.ActivePage.Free;
end;

constructor TForm1.Create(aOwner: TComponent);
begin
   inherited;
   UpdateControls;
end;

{$if defined(MonitorDPIChangeEvent)}
procedure TForm1.DoAfterMonitorDpiChanged(OldDPI, NewDPI: Integer);
  procedure UpdateDPIForControl(aWinControl: TWinControl);
  var
    I: Integer;
  begin
    if aWinControl is TChart then
      TChartConfig.ConfigureChartColors(cctDisplay, TChart(aWinControl));
    for I := 0 to aWinControl.ComponentCount-1 do
      if aWinControl.Components[I] is TWinControl then begin
        UpdateDPIForControl(TWinControl(aWinControl.Components[I]));
    end;
  end;

begin
  inherited;
  UpdateDPIForControl(self);
end;
{$endif}

procedure TForm1.DoShow;
begin
  inherited;
  srsValues.FillSampleValues(3);
  srsHistoricRate.FillSampleValues(30);
  TChartConfig.ConfigChart(chrt72t, True);
  TChartConfig.ConfigChart(chr72tHistoricRates);
end;

procedure TForm1.PageControl1Change(Sender: TObject);
begin
  UpdateControls;
end;

procedure TForm1.UMCreateImage(var aMsg: TMessage);
var
  lts: TTabSheet;
  limg: TImage;
  lChart: TChart;
  lBmp: TBitmap;
begin


  //
  // get the image object on the new tab sheet
  //
  lts := PageControl1.Pages[aMsg.LParam];
  limg := TImage(lts.Controls[0]);

  //
  // now get the chart
  //
  if aMsg.WParam = 0 then
    lChart := chrt72t
  else
    lChart := chr72tHistoricRates;

  lBmp := TBitmap.Create;
  lBmp.SetSize(lImg.Width, lImg.Height);

CodeSite.Send('lChart1', lChart);
  TChartConfig.ConfigureChartColors(cctPrinting, lChart);
  AssignChartToGraphic(lChart, lImg.BoundsRect, lbmp);
  TChartConfig.ConfigureChartColors(cctDisplay, lChart);
CodeSite.Send('lChart2', lChart);

  limg.Picture.Graphic := lbmp;
  lbmp.Free;
  UpdateControls;
end;

procedure TForm1.UpdateControls;
begin
  btnCreateImage.Enabled := PageControl1.ActivePageIndex < 2;
  btnRemoveImage.Enabled := PageControl1.ActivePageIndex > 1;
end;

end.
